==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <source>compress...</source>
        <translation type="vanished">སྡུད་སྒྲིལ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="74"/>
        <source>compress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="90"/>
        <source>uncompress to current path</source>
        <translation>འདི་རུ་བསྡུས་འགྲོལ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="101"/>
        <source>uncompress to specific path...</source>
        <translation>བསྡུས་འགྲོལ།</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>སྡུད་སྒྲིལ་བསྒར་ལྷུ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension.</source>
        <translation>ཡིག་ཚགས་ཀྱི་འདེམས་བྱང་རྒྱ་བསྐྱེད་པ།</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="66"/>
        <source>compress...</source>
        <translation>སྡུད་སྒྲིལ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="82"/>
        <source>uncompress to current path</source>
        <translation>འདི་རུ་བསྡུས་འགྲོལ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="93"/>
        <source>uncompress to specific path...</source>
        <translation>བསྡུས་འགྲོལ།</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>སྡུད་སྒྲིལ་བསྒར་ལྷུ།</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension.</source>
        <translation>ཡིག་ཚགས་ཀྱི་འདེམས་བྱང་རྒྱ་བསྐྱེད་པ།</translation>
    </message>
</context>
</TS>
